@@ -1,3 +1,4 @@
-from ecanvci.common import StructureEx, LEStructureEx
+from ecanvci.common import *
 from ecanvci.ecanvci import VciInitConfig, VciCanObj, VciDevice
-from ecanvci.helper import ECanVciHelper
\ No newline at end of file
+from ecanvci.helper import ECanVciHelper
+from ecanvci.can_record import CanRecord
\ No newline at end of file
